/**
 * @typedef {object} Options
 * @property {import('../node_modules/@types/eslint/index').ESLint.Options} [eslintOptions={}] ESLint constructor options
 * @property {boolean} [throwOnWarning=false] If `true`, will throw an error if any warnings were found.
 * @property {boolean} [throwOnError=false] If `true`, will throw an error if any errors were found.
 * @property {string} [formatter] Formatter name or path to be passed to `eslint.loadFormatter()`
 */
/**
 * @typedef {import('../node_modules/rollup').SourceMapInput} SourceMapInput
 */
export class RollupPluginESLintBundle {
    /**
     * @param {Options} [options]
     */
    constructor(options?: Options);
    name: string;
    options: Options;
    eslintOptions: ESLint.Options;
    eslint: ESLint;
    /**
     * @param {string} source
     * @param {string} modifiedSource
     * @returns {{ code: string; map: SourceMapInput }}
     */
    regenerateSourcemap(source: string, modifiedSource: string): {
        code: string;
        map: SourceMapInput;
    };
    /**
     * @param {string} source
     * @param {boolean | 'inline' | 'hidden'} sourcemap
     * @returns {Promise<{ code: string; map?: SourceMapInput } | null>}
     */
    lint(source: string, sourcemap: boolean | 'inline' | 'hidden'): Promise<{
        code: string;
        map?: SourceMapInput;
    } | null>;
}
export type Options = {
    /**
     * ESLint constructor options
     */
    eslintOptions?: import('../node_modules/@types/eslint/index').ESLint.Options;
    /**
     * If `true`, will throw an error if any warnings were found.
     */
    throwOnWarning?: boolean;
    /**
     * If `true`, will throw an error if any errors were found.
     */
    throwOnError?: boolean;
    /**
     * Formatter name or path to be passed to `eslint.loadFormatter()`
     */
    formatter?: string;
};
export type SourceMapInput = string | import("rollup").ExistingRawSourceMap | {
    mappings: "";
};
import { ESLint } from "eslint";
