"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.RollupPluginESLintBundle = void 0;

var _magicString = _interopRequireDefault(require("magic-string"));

var diff = _interopRequireWildcard(require("diff"));

var _eslint = require("eslint");

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function () { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

class RollupPluginESLintBundle {
  constructor(options = {
    eslintOptions: {}
  }) {
    this.name = 'rollup-plugin-eslint-bundle';
    this.options = options;
    this.eslintOptions = this.options.eslintOptions || {};
    this.eslint = new _eslint.ESLint(this.eslintOptions);
  }

  regenerateSourcemap(source, modifiedSource) {
    const magicString = new _magicString.default(source);
    const changes = diff.diffChars(source, modifiedSource);

    if (changes && changes.length > 0) {
      let idx = 0;
      changes.forEach(part => {
        var _part$count;

        const count = (_part$count = part.count) !== null && _part$count !== void 0 ? _part$count : 0;

        if (part.added) {
          magicString.prependLeft(idx, part.value);
          idx -= count;
        } else if (part.removed) {
          magicString.remove(idx, idx + count);
        }

        idx += count;
      });
    }

    return {
      code: magicString.toString(),
      map: magicString.generateMap({
        hires: true
      })
    };
  }

  async lint(source, sourcemap) {
    const results = await this.eslint.lintText(source);
    const result = results[0];
    const hasWarnings = result.warningCount > 0;
    const hasErrors = result.errorCount > 0;

    if (hasWarnings || hasErrors) {
      const formatter = await this.eslint.loadFormatter(this.options.formatter);
      const formattedResults = formatter.format(results);

      if (formattedResults) {
        console.log(formattedResults);
      }
    }

    const throwOnWarning = hasWarnings && this.options.throwOnWarning;
    const throwOnError = hasErrors && this.options.throwOnError;

    if (throwOnWarning && throwOnError) {
      throw Error('Warnings or errors were found');
    } else if (throwOnWarning) {
      throw Error('Warnings were found');
    } else if (throwOnError) {
      throw Error('Errors were found');
    }

    const formattedSource = result.output;

    if (!formattedSource) {
      return null;
    }

    if (!sourcemap) {
      return {
        code: formattedSource
      };
    }

    return this.regenerateSourcemap(source, formattedSource);
  }

}

exports.RollupPluginESLintBundle = RollupPluginESLintBundle;